[![Build Status](https://travis-ci.org/uw-it-cte/django-ems-wheniwork.svg?branch=master)](https://travis-ci.org/uw-it-cte/django-ems-wheniwork)
[![Coverage Status](https://coveralls.io/repos/github/uw-it-cte/django-ems-wheniwork/badge.svg?branch=master)](https://coveralls.io/github/uw-it-cte/django-ems-wheniwork?branch=master)

# django-ems-wheniwork
